#!/usr/bin/env python3

import struct
from sys import argv, exit

if len(argv) != 2:
	print('Usage: zimg.py image_file')
	exit(2)

f = open(argv[1], 'rb')

def unpack_from_file(format):
	format = '<'+format # file is little endian
	size = struct.calcsize(format)
	data = f.read(size)
	return struct.unpack(format, data)

_, _, _, img_count, _, dsize, _, _, _, version = unpack_from_file('BBHHHBBHHH') # Header
print(f'Found {img_count} images; version {version}')

has_long_palette = (dsize == 14)

for i in range(img_count):
	num, w, h, flags, a1, a2, a3 = unpack_from_file('HHHHBBB') # Directory entry, part one
	a = a1<<16 | a2<<8 | a3
	if has_long_palette:
		p1, p2, p3 = unpack_from_file('BBB')
		p = p1<<16 | p2<<8 | p3
	else:
		p = unpack_from_file('B')[0]
	
	if a: # There's an address
		print(f'Image {num}: {w} x {h}, flags {flags:#06x}, at {a:#08x} / {p:#06x}')
	elif (not w) and (not h): # There's nothing at all
		print(f'[Unused slot {num}]')
	else:
		print(f'Rect {num}: {w} x {h}, flags {flags:#06x}')
